@@ -63,6 +63,12 @@ def main():
 
     app = QtGui.QApplication(sys.argv)
     
+    config=LoadConfig()
+    
+    data.app_path=os.path.dirname(__file__)
+    if(data.app_path==""): data.app_path="./"
+    else: data.app_path=data.app_path+"/"
+    
     StartWindow = frmStartWindow()    
     CollectingWindow = frmCollectingWindow()
     LogWindow = frmLogWindow()
@@ -71,7 +77,6 @@ def main():
     StartWindow.show()      
 #    ShowLogWindow()
 
-    config=LoadConfig()
 
     StartWindow.UpdateScreenStart()
     StartWindow.show()
@@ -144,22 +149,18 @@ def ShowLogWindow():
     
     tmp= QFileDialog.getOpenFileName(None,"Open SleepCycle Log File", data.logfolder, "Log Files (*.csv)");
     tmp2=tmp.split("/")
-    l=len(tmp2)
-    data.logfilename=tmp2[l-1]
-    
-#    OpenLogFile()
-#    ProcessData()
-    
-#    LogWindow.UpdateScreen()
-
-    LogWindow.show()
-    StartWindow.hide()
+    l=len(tmp2)    
+    x=tmp2[l-1]
+    if(x==""): return #only continue if valid log file selected
+    data.logfilename=x
     
     LogWindowGraph = LogWindowCanvas()
 #    data.Xscale=1 #default zoom level
 #    LogWindowGraph.show()
     ShowLogFile()
-
+    
+    LogWindow.show()
+    StartWindow.hide()
 
 
 
@@ -242,9 +243,8 @@ def StopMeasurement():
 def RaiseTrigger():   
     data.trigger=data.trigger+1
     if(data.trigger>100): data.trigger=100
-    
     ProcessData()
-    LogWindowGraph.update() #show logWindowGraph    
+    LogWindow.update() 
     LogWindow.UpdateScreen()
     
    
@@ -256,9 +256,8 @@ def RaiseTrigger():
 def LowerTrigger():   
     data.trigger=data.trigger-1
     if(data.trigger<0): data.trigger=0
-    
     ProcessData()
-    LogWindowGraph.update() #show logWindowGraph    
+    LogWindow.update()
     LogWindow.UpdateScreen()
    
    
@@ -337,8 +336,8 @@ def showGraph(self):
         lastmove=0
 #        print shift,  data.arrDataIndex-data.derivation,  Xscale
         
-
-        for i in range(0,  data.arrDataIndex-shift-data.derivation,  Xscale):
+        end=data.arrDataIndex-shift-data.derivation
+        for i in range(0,  end,  Xscale):
             k=i+shift
             
             
@@ -364,7 +363,8 @@ def showGraph(self):
             
             #fill space between yellow movement lines
 #                if(k>lastmove+1):k
-            if(peak>data.trigger):
+#            print i,  end,  Xscale
+            if(peak>data.trigger or i>=end-Xscale):
 ##                    1=10 sec
 #                    if((i-lastmove)>30*Xscale): color="#009100" #green
 #                    elif((i-lastmove)>15*Xscale): color="#005000" #dark green
@@ -475,17 +475,15 @@ class frmStartWindow(QtGui.QWidget):
 
     def UpdateScreenStart(self):
         try:   
-            app_path=os.path.dirname(__file__)
-            if(app_path==""): app_path="./"
-            print "Application path:",  app_path
-            file = open(app_path+"/version", 'r')
+            print "Application path:",  data.app_path
+            file = open(data.app_path+"version", 'r')
             data.version = file.readline()
             data.version=data.version[:-1]
             data.build = file.readline()
         except:
             print "Version file not found"
         self.ui.lblVersion.setText(data.version+"."+data.build)
-        self.ui.lblIcon.setPixmap(QtGui.QPixmap(app_path+"/SleepAnalyser.png"))
+        self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"SleepAnalyser.png"))
 
     def closeEvent(self, event):
         global config
@@ -510,8 +508,6 @@ class frmCollectingWindow(QtGui.QWidget):
         QtCore.QObject.connect(self.ui.bStop, QtCore.SIGNAL("clicked()"), StopMeasurement)
 
     def UpdateScreen(self):
-#            self.ui.lblXacc.setText(str(data.arrData[1][data.arrDataIndex]))
-#            self.ui.lblYacc.setText(str(data.arrData[2][data.arrDataIndex]))
         if(data.demo==0):
             self.ui.lblSamples_Taken.setText(str(data.values_total))
         else:
@@ -529,9 +525,9 @@ class frmCollectingWindow(QtGui.QWidget):
         self.ui.lblStarttime.setText(t)
         self.ui.lblSamples_Taken.setText("0")
         self.ui.lblElapsedTime.setText("00:00:00")
-        self.ui.lblTrigger.setText(str(data.trigger))
-        app_path=os.path.dirname(__file__)
-        self.ui.lblIcon.setPixmap(QtGui.QPixmap(app_path+"/SleepAnalyser.png"))
+        self.ui.lblYscale.setText(str(data.Yscale))
+        self.ui.lblTrigger.setText(str(data.trigger*data.Yscale))
+        self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"SleepAnalyser.png"))
         
         
     def UpdateScreenStop(self):
@@ -570,15 +566,21 @@ class frmLogWindow(QtGui.QWidget):
         QtCore.QObject.connect(self.ui.bLast, QtCore.SIGNAL("clicked()"), LastLogFile)
         QtCore.QObject.connect(self.ui.bDelete, QtCore.SIGNAL("clicked()"), DeleteLogFile)
         
-#        self.ui.bZoomIn.setPixmap(QtGui.QPixmap(app_path+"/zoom-in.png"))
-#        self.ui.bZoomOut.setPixmap(QtGui.QPixmap(app_path+"/zoom-out.png"))
+        #only needed if application is not started in app path
+        self.ui.bZoomIn.setIcon(QIcon(data.app_path+"zoom-in.png"))
+        self.ui.bZoomOut.setIcon(QIcon(data.app_path+"zoom-out.png"))
+        self.ui.bRaiseTrigger.setIcon(QIcon(data.app_path+"go-up.png"))
+        self.ui.bLowerTrigger.setIcon(QIcon(data.app_path+"go-down.png"))
+        
+        self.ui.lblYscale.setText(str(data.Yscale))
 
 
     def UpdateScreen(self):
         self.ui.lblLogfile.setText(data.logfilename)
         self.ui.lblStarttime.setText(str(data.arrData[0][0]))
         self.ui.lblStoptime.setText(str(data.arrData[0][data.arrDataIndex-1]))
-        self.ui.lblTrigger.setText(str(data.trigger))
+        self.ui.lblTrigger.setText(str(data.trigger*data.Yscale))
+        self.ui.lblYscale.setText(str(data.Yscale))
 
 
     def DeleteLogFile(self):
